import React from "react";
import PropTypes from "prop-types";
import { Paper, Grid, Chip, Typography } from "@material-ui/core";
import styles from "../styles";
import { makeStyles } from "@material-ui/core/styles";
import { useTranslation } from "react-i18next";

const useStyles = makeStyles(styles);

const SecurityComponent = ({ userGroups, userRoles }) => {
  const { t } = useTranslation();
  const classes = useStyles();
  return (
    <Paper>
      <Grid container>
        <Grid item xs={12} md={6}>
          <div className={classes.paper}>
            <Typography gutterBottom variant="body1">
              {t("User.Profile.Security.UserGroups")}
            </Typography>
            <div>
              {userGroups.map(g => (
                <Chip key={g.code} className={classes.chip} label={g.name} />
              ))}
            </div>
          </div>
        </Grid>
        <Grid item xs={12} md={6}>
          <div className={classes.paper}>
            <Typography gutterBottom variant="body1">
              {t("User.Profile.Security.UserRoles")}
            </Typography>
            <div>
              {userRoles.map(r => (
                <Chip
                  key={r.code}
                  className={classes.chip}
                  color="primary"
                  label={r.name}
                />
              ))}
            </div>
          </div>
        </Grid>
      </Grid>
    </Paper>
  );
};

SecurityComponent.propTypes = {
  userGroups: PropTypes.array.isRequired,
  userRoles: PropTypes.array.isRequired
};

export default SecurityComponent;
